@@ -15,27 +15,27 @@ def cache_tower(tower, around, eps, safe_dist, penalize):
 
 def fill(overpass_url,file_name=None,area=None,around=1000,eps=0.01,safe_dist=100,penalize=20,max_workers=None):
     from limic.overpass import set_server, pylon, region, get_towers_by_area
-    from limic.util import start, end, file_size, load_pickled, save_pickled, verbosity, get_failed, set_failed, get_parser, replace
+    from limic.util import start, end, file_size, status, load_pickled, save_pickled, options, replace, options
     from networkx import Graph, relabel_nodes
     from os import cpu_count
     from os.path import exists
     from concurrent.futures import ThreadPoolExecutor, wait
     from signal import signal, SIGINT
     if not area and not file_name:
-        parser = get_parser()
-        if parser:
-            parser.error("specify at least one of --area or CACHE")
+        if options.parser:
+            options.parser.error("specify at least one of --area or CACHE")
         else:
-            print("ERROR: specify at least area or cache name!")
-        from sys import exit
-        exit(-1)
+            status("ERROR: specify at least area or cache name!")
+            from sys import exit
+            exit(-1)
     if not area:
         area = file_name.split(".")[1]
     if not file_name:
         file_name = "cache."+area
     if not max_workers:
         max_workers = cpu_count()*4
-    if verbosity >= 2: print("Using",max_workers,"workers!")
+    start("Number of workers")
+    status(max_workers)
     if exists(file_name):
         start("Loading",file_name)
         region.backend._cache = load_pickled(file_name)
@@ -69,9 +69,9 @@ def fill(overpass_url,file_name=None,area=None,around=1000,eps=0.01,safe_dist=10
             end('')
             file_size(file_name_tmp)
     signal(SIGINT,shutdown)
-    set_failed(True)
-    while get_failed():
-        set_failed(False)
+    options.failed = True
+    while options.failed:
+        options.failed = False
         for tower in towers:
             fs.append(executor.submit(cache_tower, tower, around, eps, safe_dist, penalize))
         running = len(fs)
