@@ -11,6 +11,7 @@ CONFIG = [
 
 def prune_ids_nx(g,delete_ids):
     to_delete = []
+    delete_ids = set(delete_ids)
     for n in g.nodes():
         if n[0] in delete_ids:
             to_delete.append(n)
@@ -20,16 +21,26 @@ def prune_ids_nx(g,delete_ids):
 
 def prune_nx(file_name_in,file_name_out,polygon,overpass_url):
     from limic.util import start, end, file_size, status, save_pickled, load_pickled, check_overwrite
-    from limic.overpass import nodes_in_geometry, set_server
     if not check_overwrite(file_name_in,file_name_out):
         return
     start("Loading from",file_name_in)
     g = load_pickled(file_name_in)
     end('')
     file_size(file_name_in)
-    start("Query server for nodes in polygon")
-    set_server(overpass_url)
-    nodes = nodes_in_geometry(zip(polygon[::2], polygon[1::2]))
+    polygon = list(map(float,polygon))
+    polygon = list(zip(polygon[::2], polygon[1::2]))
+    if not overpass_url:
+        from limic.util import kdtree, nodes_in_geometry
+        start("Building kd-tree from nodes")
+        tree = kdtree(g.nodes(),get_latlon=lambda x:(x[1],x[2]))
+        end()
+        start("Querying tree for nodes in polygon")
+        nodes = nodes_in_geometry(tree,polygon)
+    else:
+        from limic.overpass import nodes_in_geometry, set_server
+        start("Query server for nodes in polygon")
+        set_server(overpass_url)
+        nodes = nodes_in_geometry(polygon)
     end('')
     status(len(nodes))
     start("Pruning graph")
