@@ -114,7 +114,7 @@ def serve(g,nodes,astar,html_file,host="localhost",port=5000,prefix="",url=None,
             delay = 0.5
             sleep(delay)
             url = "http://%s:%d%s/" % (r_host,r_port,r_prefix)
-            start("Opening",url,"in browser")
+            start("Open",url,"in browser")
             wopen(url,new=2)
             status("DONE")
     if not no_browser:
